Keen | Input Groups
Description: Base form control examples

# Customer Relationship Management

New Order

### Input Groups

Reports

### Basic Example

Use any icon in input group from Flaticon, Fontawesome 5, Lineawesome or Socicons icons.
Left Addon
@
Some help content goes here
Right Addon
@example.com
Joint Addons
$ 0.00
Left & Right Addons
#
px

### With Icons

Easily extend form controls by adding text, buttons, icons, or button groups on either side of textual.
Left Addon
Some help content goes here
Right Addon
Joint Addons
$
Both Addons

### Sizing

Add the relative form sizing classes to the `.input-group` itself and contents within will automatically resize.
Large Input Group
Some help content goes here
Large Input Group
0.00
Small Input Group
Small Input Group

### Input Icons

Use custom icon input component to place icon inside input control.
Left Icon Input
Some help content goes here
Right Icon Input
Some help content goes here
Large Size
Some help content goes here
Small Size
Some help content goes here

### Checkboxes and Radio addons

Place any checkbox or radio option within an input group’s addon instead of text.
Left Checkbox Addon
$
Right Checkbox Addon
$
Right & Left Checkbox Addon
Left Radio Addon
$
Right Radio Addon
$
Right & Left Radio Addon

### Button Addons

Buttons in input groups must wrapped in a `.input-group-prepend` or `.input-group-append` for proper alignment and sizing. This is required due to default browser styles that cannot be overridden.
Left Addon Button
Right Addon Button
Left & Right Addon Button
Left Addon Button
Right Addon Button
Left & Right Addon Button

### Buttons With Dropdowns

The example form below demonstrates common HTML form elements that receive updated styles from Bootstrap with additional classes.
Left Button Dropdown
Some help content goes here
Right Button Dropdown
Some help content goes here
Left & Right Button Dropdown
Some help content goes here

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!